import { and, eq } from 'drizzle-orm';
import { db } from '..';
import { rounds, type RoundInsert } from '../schema/rounds';

export async function insertRound(competitionId: string, round: RoundInsert) {
	return await db.insert(rounds).values(round).returning();
}

export async function getRounds(competitionId: string) {
	return await db.select().from(rounds).where(eq(rounds.competition_id, competitionId));
}

export async function getRound(competitionId: string, roundId: string) {
	return await db
		.select()
		.from(rounds)
		.where(and(eq(rounds.competition_id, competitionId), eq(rounds.id, roundId)));
}

export async function getRoundWithMatches(competitionId: string, roundId: string) {
	return await db.query.rounds.findMany({
		where: and(eq(rounds.competition_id, competitionId), eq(rounds.id, roundId)),
		with: {
			matches: true
		}
	});
}
