import { relations } from 'drizzle-orm';
import * as t from 'drizzle-orm/pg-core';
import { matches } from './matches';
import { competitions } from './competitions';
import { enumToPgEnum, SchedulingMode } from '../../../../types';
import { timestamps, type TModelWithRelations } from '../util';
import { brackets } from './brackets';

export const schedulingModes = t.pgEnum('scheduling_modes', enumToPgEnum(SchedulingMode));

export const rounds = t.pgTable('rounds', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull(),
	round_number: t.integer('round_number').notNull(),
	nb_matches: t.integer('nb_matches').notNull(),
	competition_id: t.uuid('competition_id').notNull(),
	scheduling_mode: schedulingModes('scheduling_modes'),
	bracket_id: t.uuid('bracket_id'),
	...timestamps
});

export const roundsRelations = relations(rounds, ({ many, one }) => ({
	competition: one(competitions, {
		fields: [rounds.competition_id],
		references: [competitions.id]
	}),
	matches: many(matches),
	bracket: one(brackets, {
		fields: [rounds.bracket_id],
		references: [brackets.id]
	})
}));

export type Round = typeof rounds.$inferSelect;

export type RoundInsert = typeof rounds.$inferInsert;

export type RoundWithRelations = TModelWithRelations<'rounds'>;
